package eiaapi

import (
	"context"
	"io"
	"net/http"
	"reflect"
)

// Generated map of Parse functions to support
// dynamic reflection upon parser functions
var ParseFunctionsMap = map[string]interface{}{
	"ParseGetV2Response":                                                                      ParseGetV2Response,
	"ParseGetV2AeoResponse":                                                                   ParseGetV2AeoResponse,
	"ParseGetV2AeoRoute1Response":                                                             ParseGetV2AeoRoute1Response,
	"ParseGetV2AeoRoute1DataResponse":                                                         ParseGetV2AeoRoute1DataResponse,
	"ParsePostV2AeoRoute1DataResponse":                                                        ParsePostV2AeoRoute1DataResponse,
	"ParseGetV2AeoRoute1FacetResponse":                                                        ParseGetV2AeoRoute1FacetResponse,
	"ParseGetV2AeoRoute1FacetFacetIdResponse":                                                 ParseGetV2AeoRoute1FacetFacetIdResponse,
	"ParseGetV2Co2EmissionsResponse":                                                          ParseGetV2Co2EmissionsResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesResponse":                                    ParseGetV2Co2EmissionsCo2EmissionsAggregatesResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesDataResponse":                                ParseGetV2Co2EmissionsCo2EmissionsAggregatesDataResponse,
	"ParsePostV2Co2EmissionsCo2EmissionsAggregatesDataResponse":                               ParsePostV2Co2EmissionsCo2EmissionsAggregatesDataResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetResponse":                               ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetIdResponse":                        ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetIdResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsResponse":                         ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse":                     ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse,
	"ParsePostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse":                    ParsePostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetResponse":                    ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetResponse,
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetIdResponse":             ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetIdResponse,
	"ParseGetV2CoalResponse":                                                                  ParseGetV2CoalResponse,
	"ParseGetV2CoalAggregateProductionResponse":                                               ParseGetV2CoalAggregateProductionResponse,
	"ParseGetV2CoalAggregateProductionDataResponse":                                           ParseGetV2CoalAggregateProductionDataResponse,
	"ParsePostV2CoalAggregateProductionDataResponse":                                          ParsePostV2CoalAggregateProductionDataResponse,
	"ParseGetV2CoalAggregateProductionFacetResponse":                                          ParseGetV2CoalAggregateProductionFacetResponse,
	"ParseGetV2CoalAggregateProductionFacetFacetIdResponse":                                   ParseGetV2CoalAggregateProductionFacetFacetIdResponse,
	"ParseGetV2CoalConsumptionAndQualityResponse":                                             ParseGetV2CoalConsumptionAndQualityResponse,
	"ParseGetV2CoalConsumptionAndQualityDataResponse":                                         ParseGetV2CoalConsumptionAndQualityDataResponse,
	"ParsePostV2CoalConsumptionAndQualityDataResponse":                                        ParsePostV2CoalConsumptionAndQualityDataResponse,
	"ParseGetV2CoalConsumptionAndQualityFacetResponse":                                        ParseGetV2CoalConsumptionAndQualityFacetResponse,
	"ParseGetV2CoalConsumptionAndQualityFacetFacetIdResponse":                                 ParseGetV2CoalConsumptionAndQualityFacetFacetIdResponse,
	"ParseGetV2CoalExportsImportsQuantityPriceResponse":                                       ParseGetV2CoalExportsImportsQuantityPriceResponse,
	"ParseGetV2CoalExportsImportsQuantityPriceDataResponse":                                   ParseGetV2CoalExportsImportsQuantityPriceDataResponse,
	"ParsePostV2CoalExportsImportsQuantityPriceDataResponse":                                  ParsePostV2CoalExportsImportsQuantityPriceDataResponse,
	"ParseGetV2CoalExportsImportsQuantityPriceFacetResponse":                                  ParseGetV2CoalExportsImportsQuantityPriceFacetResponse,
	"ParseGetV2CoalExportsImportsQuantityPriceFacetFacetIdResponse":                           ParseGetV2CoalExportsImportsQuantityPriceFacetFacetIdResponse,
	"ParseGetV2CoalMarketSalesPriceResponse":                                                  ParseGetV2CoalMarketSalesPriceResponse,
	"ParseGetV2CoalMarketSalesPriceDataResponse":                                              ParseGetV2CoalMarketSalesPriceDataResponse,
	"ParsePostV2CoalMarketSalesPriceDataResponse":                                             ParsePostV2CoalMarketSalesPriceDataResponse,
	"ParseGetV2CoalMarketSalesPriceFacetResponse":                                             ParseGetV2CoalMarketSalesPriceFacetResponse,
	"ParseGetV2CoalMarketSalesPriceFacetFacetIdResponse":                                      ParseGetV2CoalMarketSalesPriceFacetFacetIdResponse,
	"ParseGetV2CoalMineProductionResponse":                                                    ParseGetV2CoalMineProductionResponse,
	"ParseGetV2CoalMineProductionDataResponse":                                                ParseGetV2CoalMineProductionDataResponse,
	"ParsePostV2CoalMineProductionDataResponse":                                               ParsePostV2CoalMineProductionDataResponse,
	"ParseGetV2CoalMineProductionFacetResponse":                                               ParseGetV2CoalMineProductionFacetResponse,
	"ParseGetV2CoalMineProductionFacetFacetIdResponse":                                        ParseGetV2CoalMineProductionFacetFacetIdResponse,
	"ParseGetV2CoalPriceByRankResponse":                                                       ParseGetV2CoalPriceByRankResponse,
	"ParseGetV2CoalPriceByRankDataResponse":                                                   ParseGetV2CoalPriceByRankDataResponse,
	"ParsePostV2CoalPriceByRankDataResponse":                                                  ParsePostV2CoalPriceByRankDataResponse,
	"ParseGetV2CoalPriceByRankFacetResponse":                                                  ParseGetV2CoalPriceByRankFacetResponse,
	"ParseGetV2CoalPriceByRankFacetFacetIdResponse":                                           ParseGetV2CoalPriceByRankFacetFacetIdResponse,
	"ParseGetV2CoalReservesCapacityResponse":                                                  ParseGetV2CoalReservesCapacityResponse,
	"ParseGetV2CoalReservesCapacityDataResponse":                                              ParseGetV2CoalReservesCapacityDataResponse,
	"ParsePostV2CoalReservesCapacityDataResponse":                                             ParsePostV2CoalReservesCapacityDataResponse,
	"ParseGetV2CoalReservesCapacityFacetResponse":                                             ParseGetV2CoalReservesCapacityFacetResponse,
	"ParseGetV2CoalReservesCapacityFacetFacetIdResponse":                                      ParseGetV2CoalReservesCapacityFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsResponse":                                                         ParseGetV2CoalShipmentsResponse,
	"ParseGetV2CoalShipmentsByMineByPlantResponse":                                            ParseGetV2CoalShipmentsByMineByPlantResponse,
	"ParseGetV2CoalShipmentsByMineByPlantDataResponse":                                        ParseGetV2CoalShipmentsByMineByPlantDataResponse,
	"ParsePostV2CoalShipmentsByMineByPlantDataResponse":                                       ParsePostV2CoalShipmentsByMineByPlantDataResponse,
	"ParseGetV2CoalShipmentsByMineByPlantFacetResponse":                                       ParseGetV2CoalShipmentsByMineByPlantFacetResponse,
	"ParseGetV2CoalShipmentsByMineByPlantFacetFacetIdResponse":                                ParseGetV2CoalShipmentsByMineByPlantFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsMineAggregatesResponse":                                           ParseGetV2CoalShipmentsMineAggregatesResponse,
	"ParseGetV2CoalShipmentsMineAggregatesDataResponse":                                       ParseGetV2CoalShipmentsMineAggregatesDataResponse,
	"ParsePostV2CoalShipmentsMineAggregatesDataResponse":                                      ParsePostV2CoalShipmentsMineAggregatesDataResponse,
	"ParseGetV2CoalShipmentsMineAggregatesFacetResponse":                                      ParseGetV2CoalShipmentsMineAggregatesFacetResponse,
	"ParseGetV2CoalShipmentsMineAggregatesFacetFacetIdResponse":                               ParseGetV2CoalShipmentsMineAggregatesFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsMineStateAggregatesResponse":                                      ParseGetV2CoalShipmentsMineStateAggregatesResponse,
	"ParseGetV2CoalShipmentsMineStateAggregatesDataResponse":                                  ParseGetV2CoalShipmentsMineStateAggregatesDataResponse,
	"ParsePostV2CoalShipmentsMineStateAggregatesDataResponse":                                 ParsePostV2CoalShipmentsMineStateAggregatesDataResponse,
	"ParseGetV2CoalShipmentsMineStateAggregatesFacetResponse":                                 ParseGetV2CoalShipmentsMineStateAggregatesFacetResponse,
	"ParseGetV2CoalShipmentsMineStateAggregatesFacetFacetIdResponse":                          ParseGetV2CoalShipmentsMineStateAggregatesFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsPlantAggregatesResponse":                                          ParseGetV2CoalShipmentsPlantAggregatesResponse,
	"ParseGetV2CoalShipmentsPlantAggregatesDataResponse":                                      ParseGetV2CoalShipmentsPlantAggregatesDataResponse,
	"ParsePostV2CoalShipmentsPlantAggregatesDataResponse":                                     ParsePostV2CoalShipmentsPlantAggregatesDataResponse,
	"ParseGetV2CoalShipmentsPlantAggregatesFacetResponse":                                     ParseGetV2CoalShipmentsPlantAggregatesFacetResponse,
	"ParseGetV2CoalShipmentsPlantAggregatesFacetFacetIdResponse":                              ParseGetV2CoalShipmentsPlantAggregatesFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsPlantStateAggregatesResponse":                                     ParseGetV2CoalShipmentsPlantStateAggregatesResponse,
	"ParseGetV2CoalShipmentsPlantStateAggregatesDataResponse":                                 ParseGetV2CoalShipmentsPlantStateAggregatesDataResponse,
	"ParsePostV2CoalShipmentsPlantStateAggregatesDataResponse":                                ParsePostV2CoalShipmentsPlantStateAggregatesDataResponse,
	"ParseGetV2CoalShipmentsPlantStateAggregatesFacetResponse":                                ParseGetV2CoalShipmentsPlantStateAggregatesFacetResponse,
	"ParseGetV2CoalShipmentsPlantStateAggregatesFacetFacetIdResponse":                         ParseGetV2CoalShipmentsPlantStateAggregatesFacetFacetIdResponse,
	"ParseGetV2CoalShipmentsReceiptsResponse":                                                 ParseGetV2CoalShipmentsReceiptsResponse,
	"ParseGetV2CoalShipmentsReceiptsDataResponse":                                             ParseGetV2CoalShipmentsReceiptsDataResponse,
	"ParsePostV2CoalShipmentsReceiptsDataResponse":                                            ParsePostV2CoalShipmentsReceiptsDataResponse,
	"ParseGetV2CoalShipmentsReceiptsFacetResponse":                                            ParseGetV2CoalShipmentsReceiptsFacetResponse,
	"ParseGetV2CoalShipmentsReceiptsFacetFacetIdResponse":                                     ParseGetV2CoalShipmentsReceiptsFacetFacetIdResponse,
	"ParseGetV2CrudeOilImportsResponse":                                                       ParseGetV2CrudeOilImportsResponse,
	"ParseGetV2CrudeOilImportsDataResponse":                                                   ParseGetV2CrudeOilImportsDataResponse,
	"ParsePostV2CrudeOilImportsDataResponse":                                                  ParsePostV2CrudeOilImportsDataResponse,
	"ParseGetV2CrudeOilImportsFacetResponse":                                                  ParseGetV2CrudeOilImportsFacetResponse,
	"ParseGetV2CrudeOilImportsFacetFacetIdResponse":                                           ParseGetV2CrudeOilImportsFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassResponse":                                                      ParseGetV2DensifiedBiomassResponse,
	"ParseGetV2DensifiedBiomassCapacityByRegionResponse":                                      ParseGetV2DensifiedBiomassCapacityByRegionResponse,
	"ParseGetV2DensifiedBiomassCapacityByRegionDataResponse":                                  ParseGetV2DensifiedBiomassCapacityByRegionDataResponse,
	"ParsePostV2DensifiedBiomassCapacityByRegionDataResponse":                                 ParsePostV2DensifiedBiomassCapacityByRegionDataResponse,
	"ParseGetV2DensifiedBiomassCapacityByRegionFacetResponse":                                 ParseGetV2DensifiedBiomassCapacityByRegionFacetResponse,
	"ParseGetV2DensifiedBiomassCapacityByRegionFacetFacetIdResponse":                          ParseGetV2DensifiedBiomassCapacityByRegionFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionResponse":                               ParseGetV2DensifiedBiomassCharacteristicsByRegionResponse,
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionDataResponse":                           ParseGetV2DensifiedBiomassCharacteristicsByRegionDataResponse,
	"ParsePostV2DensifiedBiomassCharacteristicsByRegionDataResponse":                          ParsePostV2DensifiedBiomassCharacteristicsByRegionDataResponse,
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetResponse":                          ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetResponse,
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetFacetIdResponse":                   ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassExportSalesAndPriceResponse":                                   ParseGetV2DensifiedBiomassExportSalesAndPriceResponse,
	"ParseGetV2DensifiedBiomassExportSalesAndPriceDataResponse":                               ParseGetV2DensifiedBiomassExportSalesAndPriceDataResponse,
	"ParsePostV2DensifiedBiomassExportSalesAndPriceDataResponse":                              ParsePostV2DensifiedBiomassExportSalesAndPriceDataResponse,
	"ParseGetV2DensifiedBiomassExportSalesAndPriceFacetResponse":                              ParseGetV2DensifiedBiomassExportSalesAndPriceFacetResponse,
	"ParseGetV2DensifiedBiomassExportSalesAndPriceFacetFacetIdResponse":                       ParseGetV2DensifiedBiomassExportSalesAndPriceFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassFeedstocksAndCostResponse":                                     ParseGetV2DensifiedBiomassFeedstocksAndCostResponse,
	"ParseGetV2DensifiedBiomassFeedstocksAndCostDataResponse":                                 ParseGetV2DensifiedBiomassFeedstocksAndCostDataResponse,
	"ParsePostV2DensifiedBiomassFeedstocksAndCostDataResponse":                                ParsePostV2DensifiedBiomassFeedstocksAndCostDataResponse,
	"ParseGetV2DensifiedBiomassFeedstocksAndCostFacetResponse":                                ParseGetV2DensifiedBiomassFeedstocksAndCostFacetResponse,
	"ParseGetV2DensifiedBiomassFeedstocksAndCostFacetFacetIdResponse":                         ParseGetV2DensifiedBiomassFeedstocksAndCostFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassInventoriesByRegionResponse":                                   ParseGetV2DensifiedBiomassInventoriesByRegionResponse,
	"ParseGetV2DensifiedBiomassInventoriesByRegionDataResponse":                               ParseGetV2DensifiedBiomassInventoriesByRegionDataResponse,
	"ParsePostV2DensifiedBiomassInventoriesByRegionDataResponse":                              ParsePostV2DensifiedBiomassInventoriesByRegionDataResponse,
	"ParseGetV2DensifiedBiomassInventoriesByRegionFacetResponse":                              ParseGetV2DensifiedBiomassInventoriesByRegionFacetResponse,
	"ParseGetV2DensifiedBiomassInventoriesByRegionFacetFacetIdResponse":                       ParseGetV2DensifiedBiomassInventoriesByRegionFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassProductionByRegionResponse":                                    ParseGetV2DensifiedBiomassProductionByRegionResponse,
	"ParseGetV2DensifiedBiomassProductionByRegionDataResponse":                                ParseGetV2DensifiedBiomassProductionByRegionDataResponse,
	"ParsePostV2DensifiedBiomassProductionByRegionDataResponse":                               ParsePostV2DensifiedBiomassProductionByRegionDataResponse,
	"ParseGetV2DensifiedBiomassProductionByRegionFacetResponse":                               ParseGetV2DensifiedBiomassProductionByRegionFacetResponse,
	"ParseGetV2DensifiedBiomassProductionByRegionFacetFacetIdResponse":                        ParseGetV2DensifiedBiomassProductionByRegionFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionResponse":                                 ParseGetV2DensifiedBiomassSalesAndPriceByRegionResponse,
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionDataResponse":                             ParseGetV2DensifiedBiomassSalesAndPriceByRegionDataResponse,
	"ParsePostV2DensifiedBiomassSalesAndPriceByRegionDataResponse":                            ParsePostV2DensifiedBiomassSalesAndPriceByRegionDataResponse,
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetResponse":                            ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetResponse,
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetIdResponse":                     ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetIdResponse,
	"ParseGetV2DensifiedBiomassWoodPelletPlantsResponse":                                      ParseGetV2DensifiedBiomassWoodPelletPlantsResponse,
	"ParseGetV2DensifiedBiomassWoodPelletPlantsDataResponse":                                  ParseGetV2DensifiedBiomassWoodPelletPlantsDataResponse,
	"ParsePostV2DensifiedBiomassWoodPelletPlantsDataResponse":                                 ParsePostV2DensifiedBiomassWoodPelletPlantsDataResponse,
	"ParseGetV2DensifiedBiomassWoodPelletPlantsFacetResponse":                                 ParseGetV2DensifiedBiomassWoodPelletPlantsFacetResponse,
	"ParseGetV2DensifiedBiomassWoodPelletPlantsFacetFacetIdResponse":                          ParseGetV2DensifiedBiomassWoodPelletPlantsFacetFacetIdResponse,
	"ParseGetV2ElectricityResponse":                                                           ParseGetV2ElectricityResponse,
	"ParseGetV2ElectricityElectricPowerOperationalDataResponse":                               ParseGetV2ElectricityElectricPowerOperationalDataResponse,
	"ParseGetV2ElectricityElectricPowerOperationalDataDataResponse":                           ParseGetV2ElectricityElectricPowerOperationalDataDataResponse,
	"ParsePostV2ElectricityElectricPowerOperationalDataDataResponse":                          ParsePostV2ElectricityElectricPowerOperationalDataDataResponse,
	"ParseGetV2ElectricityElectricPowerOperationalDataFacetResponse":                          ParseGetV2ElectricityElectricPowerOperationalDataFacetResponse,
	"ParseGetV2ElectricityElectricPowerOperationalDataFacetFacetIdResponse":                   ParseGetV2ElectricityElectricPowerOperationalDataFacetFacetIdResponse,
	"ParseGetV2ElectricityFacilityFuelResponse":                                               ParseGetV2ElectricityFacilityFuelResponse,
	"ParseGetV2ElectricityFacilityFuelDataResponse":                                           ParseGetV2ElectricityFacilityFuelDataResponse,
	"ParsePostV2ElectricityFacilityFuelDataResponse":                                          ParsePostV2ElectricityFacilityFuelDataResponse,
	"ParseGetV2ElectricityFacilityFuelFacetResponse":                                          ParseGetV2ElectricityFacilityFuelFacetResponse,
	"ParseGetV2ElectricityFacilityFuelFacetFacetIdResponse":                                   ParseGetV2ElectricityFacilityFuelFacetFacetIdResponse,
	"ParseGetV2ElectricityOperatingGeneratorCapacityResponse":                                 ParseGetV2ElectricityOperatingGeneratorCapacityResponse,
	"ParseGetV2ElectricityOperatingGeneratorCapacityDataResponse":                             ParseGetV2ElectricityOperatingGeneratorCapacityDataResponse,
	"ParsePostV2ElectricityOperatingGeneratorCapacityDataResponse":                            ParsePostV2ElectricityOperatingGeneratorCapacityDataResponse,
	"ParseGetV2ElectricityOperatingGeneratorCapacityFacetResponse":                            ParseGetV2ElectricityOperatingGeneratorCapacityFacetResponse,
	"ParseGetV2ElectricityOperatingGeneratorCapacityFacetFacetIdResponse":                     ParseGetV2ElectricityOperatingGeneratorCapacityFacetFacetIdResponse,
	"ParseGetV2ElectricityRetailSalesResponse":                                                ParseGetV2ElectricityRetailSalesResponse,
	"ParseGetV2ElectricityRetailSalesDataResponse":                                            ParseGetV2ElectricityRetailSalesDataResponse,
	"ParsePostV2ElectricityRetailSalesDataResponse":                                           ParsePostV2ElectricityRetailSalesDataResponse,
	"ParseGetV2ElectricityRetailSalesFacetResponse":                                           ParseGetV2ElectricityRetailSalesFacetResponse,
	"ParseGetV2ElectricityRetailSalesFacetFacetIdResponse":                                    ParseGetV2ElectricityRetailSalesFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoResponse":                                                        ParseGetV2ElectricityRtoResponse,
	"ParseGetV2ElectricityRtoDailyFuelTypeDataResponse":                                       ParseGetV2ElectricityRtoDailyFuelTypeDataResponse,
	"ParseGetV2ElectricityRtoDailyFuelTypeDataDataResponse":                                   ParseGetV2ElectricityRtoDailyFuelTypeDataDataResponse,
	"ParsePostV2ElectricityRtoDailyFuelTypeDataDataResponse":                                  ParsePostV2ElectricityRtoDailyFuelTypeDataDataResponse,
	"ParseGetV2ElectricityRtoDailyFuelTypeDataFacetResponse":                                  ParseGetV2ElectricityRtoDailyFuelTypeDataFacetResponse,
	"ParseGetV2ElectricityRtoDailyFuelTypeDataFacetFacetIdResponse":                           ParseGetV2ElectricityRtoDailyFuelTypeDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoDailyInterchangeDataResponse":                                    ParseGetV2ElectricityRtoDailyInterchangeDataResponse,
	"ParseGetV2ElectricityRtoDailyInterchangeDataDataResponse":                                ParseGetV2ElectricityRtoDailyInterchangeDataDataResponse,
	"ParsePostV2ElectricityRtoDailyInterchangeDataDataResponse":                               ParsePostV2ElectricityRtoDailyInterchangeDataDataResponse,
	"ParseGetV2ElectricityRtoDailyInterchangeDataFacetResponse":                               ParseGetV2ElectricityRtoDailyInterchangeDataFacetResponse,
	"ParseGetV2ElectricityRtoDailyInterchangeDataFacetFacetIdResponse":                        ParseGetV2ElectricityRtoDailyInterchangeDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoDailyRegionDataResponse":                                         ParseGetV2ElectricityRtoDailyRegionDataResponse,
	"ParseGetV2ElectricityRtoDailyRegionDataDataResponse":                                     ParseGetV2ElectricityRtoDailyRegionDataDataResponse,
	"ParsePostV2ElectricityRtoDailyRegionDataDataResponse":                                    ParsePostV2ElectricityRtoDailyRegionDataDataResponse,
	"ParseGetV2ElectricityRtoDailyRegionDataFacetResponse":                                    ParseGetV2ElectricityRtoDailyRegionDataFacetResponse,
	"ParseGetV2ElectricityRtoDailyRegionDataFacetFacetIdResponse":                             ParseGetV2ElectricityRtoDailyRegionDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataResponse":                                    ParseGetV2ElectricityRtoDailyRegionSubBaDataResponse,
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataDataResponse":                                ParseGetV2ElectricityRtoDailyRegionSubBaDataDataResponse,
	"ParsePostV2ElectricityRtoDailyRegionSubBaDataDataResponse":                               ParsePostV2ElectricityRtoDailyRegionSubBaDataDataResponse,
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetResponse":                               ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetResponse,
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetFacetIdResponse":                        ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoFuelTypeDataResponse":                                            ParseGetV2ElectricityRtoFuelTypeDataResponse,
	"ParseGetV2ElectricityRtoFuelTypeDataDataResponse":                                        ParseGetV2ElectricityRtoFuelTypeDataDataResponse,
	"ParsePostV2ElectricityRtoFuelTypeDataDataResponse":                                       ParsePostV2ElectricityRtoFuelTypeDataDataResponse,
	"ParseGetV2ElectricityRtoFuelTypeDataFacetResponse":                                       ParseGetV2ElectricityRtoFuelTypeDataFacetResponse,
	"ParseGetV2ElectricityRtoFuelTypeDataFacetFacetIdResponse":                                ParseGetV2ElectricityRtoFuelTypeDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoInterchangeDataResponse":                                         ParseGetV2ElectricityRtoInterchangeDataResponse,
	"ParseGetV2ElectricityRtoInterchangeDataDataResponse":                                     ParseGetV2ElectricityRtoInterchangeDataDataResponse,
	"ParsePostV2ElectricityRtoInterchangeDataDataResponse":                                    ParsePostV2ElectricityRtoInterchangeDataDataResponse,
	"ParseGetV2ElectricityRtoInterchangeDataFacetResponse":                                    ParseGetV2ElectricityRtoInterchangeDataFacetResponse,
	"ParseGetV2ElectricityRtoInterchangeDataFacetFacetIdResponse":                             ParseGetV2ElectricityRtoInterchangeDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoRegionDataResponse":                                              ParseGetV2ElectricityRtoRegionDataResponse,
	"ParseGetV2ElectricityRtoRegionDataDataResponse":                                          ParseGetV2ElectricityRtoRegionDataDataResponse,
	"ParsePostV2ElectricityRtoRegionDataDataResponse":                                         ParsePostV2ElectricityRtoRegionDataDataResponse,
	"ParseGetV2ElectricityRtoRegionDataFacetResponse":                                         ParseGetV2ElectricityRtoRegionDataFacetResponse,
	"ParseGetV2ElectricityRtoRegionDataFacetFacetIdResponse":                                  ParseGetV2ElectricityRtoRegionDataFacetFacetIdResponse,
	"ParseGetV2ElectricityRtoRegionSubBaDataResponse":                                         ParseGetV2ElectricityRtoRegionSubBaDataResponse,
	"ParseGetV2ElectricityRtoRegionSubBaDataDataResponse":                                     ParseGetV2ElectricityRtoRegionSubBaDataDataResponse,
	"ParsePostV2ElectricityRtoRegionSubBaDataDataResponse":                                    ParsePostV2ElectricityRtoRegionSubBaDataDataResponse,
	"ParseGetV2ElectricityRtoRegionSubBaDataFacetResponse":                                    ParseGetV2ElectricityRtoRegionSubBaDataFacetResponse,
	"ParseGetV2ElectricityRtoRegionSubBaDataFacetFacetIdResponse":                             ParseGetV2ElectricityRtoRegionSubBaDataFacetFacetIdResponse,
	"ParseGetV2ElectricitySepResponse":                                                        ParseGetV2ElectricitySepResponse,
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityResponse":                         ParseGetV2ElectricityStateElectricityProfilesCapabilityResponse,
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityDataResponse":                     ParseGetV2ElectricityStateElectricityProfilesCapabilityDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesCapabilityDataResponse":                    ParsePostV2ElectricityStateElectricityProfilesCapabilityDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetResponse":                    ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetFacetIdResponse":             ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelResponse":             ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse":         ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse":        ParsePostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetResponse":        ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetIdResponse": ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyResponse":                   ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse":               ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse":              ParsePostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetResponse":              ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetIdResponse":       ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesMetersResponse":                             ParseGetV2ElectricityStateElectricityProfilesMetersResponse,
	"ParseGetV2ElectricityStateElectricityProfilesMetersDataResponse":                         ParseGetV2ElectricityStateElectricityProfilesMetersDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesMetersDataResponse":                        ParsePostV2ElectricityStateElectricityProfilesMetersDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesMetersFacetResponse":                        ParseGetV2ElectricityStateElectricityProfilesMetersFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesMetersFacetFacetIdResponse":                 ParseGetV2ElectricityStateElectricityProfilesMetersFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringResponse":                        ParseGetV2ElectricityStateElectricityProfilesNetMeteringResponse,
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringDataResponse":                    ParseGetV2ElectricityStateElectricityProfilesNetMeteringDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesNetMeteringDataResponse":                   ParsePostV2ElectricityStateElectricityProfilesNetMeteringDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetResponse":                   ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetIdResponse":            ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionResponse":                  ParseGetV2ElectricityStateElectricityProfilesSourceDispositionResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionDataResponse":              ParseGetV2ElectricityStateElectricityProfilesSourceDispositionDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesSourceDispositionDataResponse":             ParsePostV2ElectricityStateElectricityProfilesSourceDispositionDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetResponse":             ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetIdResponse":      ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetIdResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSummaryResponse":                            ParseGetV2ElectricityStateElectricityProfilesSummaryResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSummaryDataResponse":                        ParseGetV2ElectricityStateElectricityProfilesSummaryDataResponse,
	"ParsePostV2ElectricityStateElectricityProfilesSummaryDataResponse":                       ParsePostV2ElectricityStateElectricityProfilesSummaryDataResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSummaryFacetResponse":                       ParseGetV2ElectricityStateElectricityProfilesSummaryFacetResponse,
	"ParseGetV2ElectricityStateElectricityProfilesSummaryFacetFacetIdResponse":                ParseGetV2ElectricityStateElectricityProfilesSummaryFacetFacetIdResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerIeoResponse":                             ParseEIAAPIControllersDatasetAeoIeoIeoControllerIeoResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerConstructResponse":                       ParseEIAAPIControllersDatasetAeoIeoIeoControllerConstructResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerGetDataResponse":                         ParseEIAAPIControllersDatasetAeoIeoIeoControllerGetDataResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerPostDataResponse":                        ParseEIAAPIControllersDatasetAeoIeoIeoControllerPostDataResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetResponse":                      ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetResponse,
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetIdResponse":                    ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetIdResponse,
	"ParseGetV2InternationalResponse":                                                         ParseGetV2InternationalResponse,
	"ParseGetV2InternationalDataResponse":                                                     ParseGetV2InternationalDataResponse,
	"ParsePostV2InternationalDataResponse":                                                    ParsePostV2InternationalDataResponse,
	"ParseGetV2InternationalFacetResponse":                                                    ParseGetV2InternationalFacetResponse,
	"ParseGetV2InternationalFacetFacetIdResponse":                                             ParseGetV2InternationalFacetFacetIdResponse,
	"ParseGetV2NaturalGasResponse":                                                            ParseGetV2NaturalGasResponse,
	"ParseGetV2NaturalGasRoute1Response":                                                      ParseGetV2NaturalGasRoute1Response,
	"ParseGetV2NaturalGasRoute1Route2Response":                                                ParseGetV2NaturalGasRoute1Route2Response,
	"ParseGetV2NaturalGasRoute1Route2DataResponse":                                            ParseGetV2NaturalGasRoute1Route2DataResponse,
	"ParsePostV2NaturalGasRoute1Route2DataResponse":                                           ParsePostV2NaturalGasRoute1Route2DataResponse,
	"ParseGetV2NaturalGasRoute1Route2FacetResponse":                                           ParseGetV2NaturalGasRoute1Route2FacetResponse,
	"ParseGetV2NaturalGasRoute1Route2FacetFacetIdResponse":                                    ParseGetV2NaturalGasRoute1Route2FacetFacetIdResponse,
	"ParseGetV2NuclearOutagesResponse":                                                        ParseGetV2NuclearOutagesResponse,
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesResponse":                                  ParseGetV2NuclearOutagesFacilityNuclearOutagesResponse,
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesDataResponse":                              ParseGetV2NuclearOutagesFacilityNuclearOutagesDataResponse,
	"ParsePostV2NuclearOutagesFacilityNuclearOutagesDataResponse":                             ParsePostV2NuclearOutagesFacilityNuclearOutagesDataResponse,
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetResponse":                             ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetResponse,
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetFacetIdResponse":                      ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetFacetIdResponse,
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesResponse":                                 ParseGetV2NuclearOutagesGeneratorNuclearOutagesResponse,
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesDataResponse":                             ParseGetV2NuclearOutagesGeneratorNuclearOutagesDataResponse,
	"ParsePostV2NuclearOutagesGeneratorNuclearOutagesDataResponse":                            ParsePostV2NuclearOutagesGeneratorNuclearOutagesDataResponse,
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetResponse":                            ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetResponse,
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetIdResponse":                     ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetIdResponse,
	"ParseGetV2NuclearOutagesUsNuclearOutagesResponse":                                        ParseGetV2NuclearOutagesUsNuclearOutagesResponse,
	"ParseGetV2NuclearOutagesUsNuclearOutagesDataResponse":                                    ParseGetV2NuclearOutagesUsNuclearOutagesDataResponse,
	"ParsePostV2NuclearOutagesUsNuclearOutagesDataResponse":                                   ParsePostV2NuclearOutagesUsNuclearOutagesDataResponse,
	"ParseGetV2NuclearOutagesUsNuclearOutagesFacetResponse":                                   ParseGetV2NuclearOutagesUsNuclearOutagesFacetResponse,
	"ParseGetV2NuclearOutagesUsNuclearOutagesFacetFacetIdResponse":                            ParseGetV2NuclearOutagesUsNuclearOutagesFacetFacetIdResponse,
	"ParseGetV2SedsResponse":                                                                  ParseGetV2SedsResponse,
	"ParseGetV2SedsDataResponse":                                                              ParseGetV2SedsDataResponse,
	"ParsePostV2SedsDataResponse":                                                             ParsePostV2SedsDataResponse,
	"ParseGetV2SedsFacetResponse":                                                             ParseGetV2SedsFacetResponse,
	"ParseGetV2SedsFacetFacetIdResponse":                                                      ParseGetV2SedsFacetFacetIdResponse,
	"ParseGetV2SteoResponse":                                                                  ParseGetV2SteoResponse,
	"ParseGetV2SteoDataResponse":                                                              ParseGetV2SteoDataResponse,
	"ParsePostV2SteoDataResponse":                                                             ParsePostV2SteoDataResponse,
	"ParseGetV2SteoFacetResponse":                                                             ParseGetV2SteoFacetResponse,
	"ParseGetV2SteoFacetFacetIdResponse":                                                      ParseGetV2SteoFacetFacetIdResponse,
	"ParseGetV2TotalEnergyResponse":                                                           ParseGetV2TotalEnergyResponse,
	"ParseGetV2TotalEnergyDataResponse":                                                       ParseGetV2TotalEnergyDataResponse,
	"ParsePostV2TotalEnergyDataResponse":                                                      ParsePostV2TotalEnergyDataResponse,
	"ParseGetV2TotalEnergyFacetResponse":                                                      ParseGetV2TotalEnergyFacetResponse,
	"ParseGetV2TotalEnergyFacetFacetIdResponse":                                               ParseGetV2TotalEnergyFacetFacetIdResponse,
}

var FunctionParams = map[string][]reflect.Type{
	"NewClient": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"WithHTTPClient": {
		reflect.TypeOf((*HttpRequestDoer)(nil)).Elem(),
	},
	"WithRequestEditorFn": {
		reflect.TypeOf((*RequestEditorFn)(nil)).Elem(),
	},
	"GetV2": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Aeo": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2AeoRoute1": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2AeoRoute1Data": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*GetV2AeoRoute1DataParams)(nil)).Elem(),
	},
	"PostV2AeoRoute1DataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2AeoRoute1Data": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*PostV2AeoRoute1DataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2AeoRoute1Facet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"GetV2AeoRoute1FacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Co2Emissions": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregates": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAggregatesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficients": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataParams)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Coal": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProduction": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalAggregateProductionDataParams)(nil)).Elem(),
	},
	"PostV2CoalAggregateProductionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalAggregateProductionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalAggregateProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQuality": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalConsumptionAndQualityDataParams)(nil)).Elem(),
	},
	"PostV2CoalConsumptionAndQualityDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalConsumptionAndQualityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalConsumptionAndQualityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPrice": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalExportsImportsQuantityPriceDataParams)(nil)).Elem(),
	},
	"PostV2CoalExportsImportsQuantityPriceDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalExportsImportsQuantityPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalExportsImportsQuantityPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPrice": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMarketSalesPriceDataParams)(nil)).Elem(),
	},
	"PostV2CoalMarketSalesPriceDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalMarketSalesPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMarketSalesPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalMineProduction": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMineProductionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMineProductionDataParams)(nil)).Elem(),
	},
	"PostV2CoalMineProductionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalMineProductionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMineProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalMineProductionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMineProductionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalPriceByRank": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalPriceByRankDataParams)(nil)).Elem(),
	},
	"PostV2CoalPriceByRankDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalPriceByRankData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalPriceByRankDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacity": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalReservesCapacityDataParams)(nil)).Elem(),
	},
	"PostV2CoalReservesCapacityDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalReservesCapacityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalReservesCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipments": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlant": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsByMineByPlantDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsByMineByPlantDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsByMineByPlantData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsByMineByPlantDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregates": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineAggregatesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregates": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineStateAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineStateAggregatesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineStateAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregates": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantAggregatesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregates": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantStateAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantStateAggregatesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantStateAggregatesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceipts": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsReceiptsDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsReceiptsDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsReceiptsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsReceiptsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CrudeOilImports": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CrudeOilImportsDataParams)(nil)).Elem(),
	},
	"PostV2CrudeOilImportsDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CrudeOilImportsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CrudeOilImportsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomass": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegion": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCapacityByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCapacityByRegionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCapacityByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCapacityByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegion": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCharacteristicsByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCharacteristicsByRegionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCharacteristicsByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCharacteristicsByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPrice": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassExportSalesAndPriceDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassExportSalesAndPriceDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassExportSalesAndPriceData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassExportSalesAndPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCost": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassFeedstocksAndCostDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassFeedstocksAndCostDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassFeedstocksAndCostData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassFeedstocksAndCostDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegion": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassInventoriesByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassInventoriesByRegionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassInventoriesByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassInventoriesByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegion": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassProductionByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassProductionByRegionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassProductionByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassProductionByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegion": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassSalesAndPriceByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassSalesAndPriceByRegionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassSalesAndPriceByRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassSalesAndPriceByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlants": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassWoodPelletPlantsDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassWoodPelletPlantsDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassWoodPelletPlantsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassWoodPelletPlantsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Electricity": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityElectricPowerOperationalDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityElectricPowerOperationalDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityElectricPowerOperationalDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityElectricPowerOperationalDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuel": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityFacilityFuelDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityFacilityFuelDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityFacilityFuelData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityFacilityFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacity": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityOperatingGeneratorCapacityDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityOperatingGeneratorCapacityDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityOperatingGeneratorCapacityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityOperatingGeneratorCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSales": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRetailSalesDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRetailSalesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRetailSalesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRetailSalesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRto": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyFuelTypeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyFuelTypeDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyFuelTypeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyInterchangeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyInterchangeDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyInterchangeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionSubBaDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionSubBaDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoFuelTypeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoFuelTypeDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoFuelTypeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoInterchangeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoInterchangeDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoInterchangeDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionSubBaDataDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionSubBaDataData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricitySep": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapability": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesCapabilityDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesCapabilityDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesCapabilityData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesCapabilityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuel": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiency": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEnergyEfficiencyData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMeters": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesMetersDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesMetersDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesMetersData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesMetersDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMetering": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesNetMeteringDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesNetMeteringDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesNetMeteringData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesNetMeteringDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDisposition": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSourceDispositionDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSourceDispositionDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSourceDispositionData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSourceDispositionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummary": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSummaryDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSummaryDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSummaryData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSummaryDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerIeo": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerConstruct": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerGetData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerGetDataParams)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerPostDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerPostData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerPostDataJSONRequestBody)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerRouteFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2International": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2InternationalData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2InternationalDataParams)(nil)).Elem(),
	},
	"PostV2InternationalDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2InternationalData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2InternationalDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2InternationalFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2InternationalFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NaturalGas": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2Data": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*GetV2NaturalGasRoute1Route2DataParams)(nil)).Elem(),
	},
	"PostV2NaturalGasRoute1Route2DataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NaturalGasRoute1Route2Data": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*PostV2NaturalGasRoute1Route2DataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2Facet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2FacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutages": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutages": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesFacilityNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesFacilityNuclearOutagesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesFacilityNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesFacilityNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutages": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesGeneratorNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesGeneratorNuclearOutagesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesGeneratorNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesGeneratorNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutages": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesUsNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesUsNuclearOutagesDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesUsNuclearOutagesData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesUsNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Seds": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SedsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2SedsDataParams)(nil)).Elem(),
	},
	"PostV2SedsDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2SedsData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2SedsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2SedsFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SedsFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2Steo": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SteoData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2SteoDataParams)(nil)).Elem(),
	},
	"PostV2SteoDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2SteoData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2SteoDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2SteoFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SteoFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2TotalEnergy": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2TotalEnergyData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2TotalEnergyDataParams)(nil)).Elem(),
	},
	"PostV2TotalEnergyDataWithBody": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2TotalEnergyData": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2TotalEnergyDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2TotalEnergyFacet": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2TotalEnergyFacetFacetId": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2Request": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2AeoRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2AeoRoute1Request": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2AeoRoute1DataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*GetV2AeoRoute1DataParams)(nil)).Elem(),
	},
	"NewPostV2AeoRoute1DataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*PostV2AeoRoute1DataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2AeoRoute1DataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2AeoRoute1FacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"NewGetV2AeoRoute1FacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAggregatesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAggregatesDataParams)(nil)).Elem(),
	},
	"NewPostV2Co2EmissionsCo2EmissionsAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2Co2EmissionsCo2EmissionsAggregatesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAggregatesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataParams)(nil)).Elem(),
	},
	"NewPostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalAggregateProductionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalAggregateProductionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalAggregateProductionDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalAggregateProductionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalAggregateProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalAggregateProductionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalAggregateProductionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalAggregateProductionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalConsumptionAndQualityRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalConsumptionAndQualityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalConsumptionAndQualityDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalConsumptionAndQualityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalConsumptionAndQualityDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalConsumptionAndQualityDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalConsumptionAndQualityFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalConsumptionAndQualityFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalExportsImportsQuantityPriceRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalExportsImportsQuantityPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalExportsImportsQuantityPriceDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalExportsImportsQuantityPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalExportsImportsQuantityPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalExportsImportsQuantityPriceDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalExportsImportsQuantityPriceFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalExportsImportsQuantityPriceFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalMarketSalesPriceRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalMarketSalesPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMarketSalesPriceDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalMarketSalesPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMarketSalesPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalMarketSalesPriceDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalMarketSalesPriceFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalMarketSalesPriceFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalMineProductionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalMineProductionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMineProductionDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalMineProductionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMineProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalMineProductionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalMineProductionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalMineProductionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalPriceByRankRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalPriceByRankDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalPriceByRankDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalPriceByRankDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalPriceByRankDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalPriceByRankDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalPriceByRankFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalPriceByRankFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalReservesCapacityRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalReservesCapacityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalReservesCapacityDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalReservesCapacityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalReservesCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalReservesCapacityDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalReservesCapacityFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalReservesCapacityFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsByMineByPlantRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsByMineByPlantDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsByMineByPlantDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsByMineByPlantDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsByMineByPlantDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsByMineByPlantDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsByMineByPlantFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsByMineByPlantFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineAggregatesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineAggregatesDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsMineAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsMineAggregatesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineAggregatesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineAggregatesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineStateAggregatesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineStateAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineStateAggregatesDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsMineStateAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsMineStateAggregatesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineStateAggregatesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsMineStateAggregatesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantAggregatesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantAggregatesDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsPlantAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsPlantAggregatesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantAggregatesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantAggregatesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantStateAggregatesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantStateAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantStateAggregatesDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsPlantStateAggregatesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsPlantStateAggregatesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantStateAggregatesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsPlantStateAggregatesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsReceiptsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsReceiptsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsReceiptsDataParams)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsReceiptsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsReceiptsDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CoalShipmentsReceiptsDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsReceiptsFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CoalShipmentsReceiptsFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2CrudeOilImportsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CrudeOilImportsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2CrudeOilImportsDataParams)(nil)).Elem(),
	},
	"NewPostV2CrudeOilImportsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2CrudeOilImportsDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2CrudeOilImportsDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2CrudeOilImportsFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2CrudeOilImportsFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCapacityByRegionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCapacityByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCapacityByRegionDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassCapacityByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCapacityByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassCapacityByRegionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCapacityByRegionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCapacityByRegionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCharacteristicsByRegionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCharacteristicsByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCharacteristicsByRegionDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassCharacteristicsByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCharacteristicsByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassCharacteristicsByRegionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCharacteristicsByRegionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassCharacteristicsByRegionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassExportSalesAndPriceRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassExportSalesAndPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassExportSalesAndPriceDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassExportSalesAndPriceDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassExportSalesAndPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassExportSalesAndPriceDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassExportSalesAndPriceFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassExportSalesAndPriceFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassFeedstocksAndCostRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassFeedstocksAndCostDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassFeedstocksAndCostDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassFeedstocksAndCostDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassFeedstocksAndCostDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassFeedstocksAndCostDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassFeedstocksAndCostFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassFeedstocksAndCostFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassInventoriesByRegionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassInventoriesByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassInventoriesByRegionDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassInventoriesByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassInventoriesByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassInventoriesByRegionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassInventoriesByRegionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassInventoriesByRegionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassProductionByRegionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassProductionByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassProductionByRegionDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassProductionByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassProductionByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassProductionByRegionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassProductionByRegionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassProductionByRegionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassSalesAndPriceByRegionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassSalesAndPriceByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassSalesAndPriceByRegionDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassSalesAndPriceByRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassSalesAndPriceByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassSalesAndPriceByRegionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassSalesAndPriceByRegionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassWoodPelletPlantsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassWoodPelletPlantsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassWoodPelletPlantsDataParams)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassWoodPelletPlantsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassWoodPelletPlantsDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2DensifiedBiomassWoodPelletPlantsDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassWoodPelletPlantsFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2DensifiedBiomassWoodPelletPlantsFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityElectricPowerOperationalDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityElectricPowerOperationalDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityElectricPowerOperationalDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityElectricPowerOperationalDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityElectricPowerOperationalDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityElectricPowerOperationalDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityElectricPowerOperationalDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityElectricPowerOperationalDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityFacilityFuelRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityFacilityFuelDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityFacilityFuelDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityFacilityFuelDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityFacilityFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityFacilityFuelDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityFacilityFuelFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityFacilityFuelFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityOperatingGeneratorCapacityRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityOperatingGeneratorCapacityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityOperatingGeneratorCapacityDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityOperatingGeneratorCapacityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityOperatingGeneratorCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityOperatingGeneratorCapacityDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityOperatingGeneratorCapacityFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityOperatingGeneratorCapacityFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRetailSalesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRetailSalesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRetailSalesDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRetailSalesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRetailSalesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRetailSalesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRetailSalesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRetailSalesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyFuelTypeDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyFuelTypeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyFuelTypeDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyFuelTypeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyFuelTypeDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyFuelTypeDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyFuelTypeDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyInterchangeDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyInterchangeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyInterchangeDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyInterchangeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyInterchangeDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyInterchangeDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyInterchangeDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyRegionDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyRegionDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionSubBaDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionSubBaDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyRegionSubBaDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoDailyRegionSubBaDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionSubBaDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoDailyRegionSubBaDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoFuelTypeDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoFuelTypeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoFuelTypeDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoFuelTypeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoFuelTypeDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoFuelTypeDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoFuelTypeDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoInterchangeDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoInterchangeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoInterchangeDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoInterchangeDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoInterchangeDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoInterchangeDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoInterchangeDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoRegionDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoRegionDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionSubBaDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionSubBaDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoRegionSubBaDataDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityRtoRegionSubBaDataDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionSubBaDataFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityRtoRegionSubBaDataFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricitySepRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesCapabilityRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesCapabilityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesCapabilityDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesCapabilityDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesCapabilityDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesCapabilityDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesCapabilityFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesCapabilityFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEnergyEfficiencyRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesMetersRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesMetersDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesMetersDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesMetersDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesMetersDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesMetersDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesMetersFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesMetersFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesNetMeteringRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesNetMeteringDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesNetMeteringDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesNetMeteringDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesNetMeteringDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesNetMeteringDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesNetMeteringFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSourceDispositionRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSourceDispositionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSourceDispositionDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesSourceDispositionDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSourceDispositionDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesSourceDispositionDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSourceDispositionFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSummaryRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSummaryDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSummaryDataParams)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesSummaryDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSummaryDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2ElectricityStateElectricityProfilesSummaryDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSummaryFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2ElectricityStateElectricityProfilesSummaryFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerIeoRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerConstructRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerGetDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerGetDataParams)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerPostDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerPostDataJSONRequestBody)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerPostDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2InternationalRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2InternationalDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2InternationalDataParams)(nil)).Elem(),
	},
	"NewPostV2InternationalDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2InternationalDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2InternationalDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2InternationalFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2InternationalFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRoute1Request": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRoute1Route2Request": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRoute1Route2DataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*GetV2NaturalGasRoute1Route2DataParams)(nil)).Elem(),
	},
	"NewPostV2NaturalGasRoute1Route2DataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*PostV2NaturalGasRoute1Route2DataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2NaturalGasRoute1Route2DataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRoute1Route2FacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"NewGetV2NaturalGasRoute1Route2FacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesFacilityNuclearOutagesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesFacilityNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesFacilityNuclearOutagesDataParams)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesFacilityNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesFacilityNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesFacilityNuclearOutagesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesFacilityNuclearOutagesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesFacilityNuclearOutagesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesGeneratorNuclearOutagesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesGeneratorNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesGeneratorNuclearOutagesDataParams)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesGeneratorNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesGeneratorNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesGeneratorNuclearOutagesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesGeneratorNuclearOutagesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesUsNuclearOutagesRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesUsNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesUsNuclearOutagesDataParams)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesUsNuclearOutagesDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesUsNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2NuclearOutagesUsNuclearOutagesDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesUsNuclearOutagesFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2NuclearOutagesUsNuclearOutagesFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewGetV2SedsRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2SedsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2SedsDataParams)(nil)).Elem(),
	},
	"NewPostV2SedsDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2SedsDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2SedsDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2SedsFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2SedsFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2SteoRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2SteoDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2SteoDataParams)(nil)).Elem(),
	},
	"NewPostV2SteoDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2SteoDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2SteoDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2SteoFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2SteoFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2TotalEnergyRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2TotalEnergyDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*GetV2TotalEnergyDataParams)(nil)).Elem(),
	},
	"NewPostV2TotalEnergyDataRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*PostV2TotalEnergyDataJSONRequestBody)(nil)).Elem(),
	},
	"NewPostV2TotalEnergyDataRequestWithBody": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"NewGetV2TotalEnergyFacetRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"NewGetV2TotalEnergyFacetFacetIdRequest": {
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"NewClientWithResponses": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"WithBaseURL": {
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2WithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2AeoWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2AeoRoute1WithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2AeoRoute1DataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*GetV2AeoRoute1DataParams)(nil)).Elem(),
	},
	"PostV2AeoRoute1DataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2AeoRoute1DataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*PostV2AeoRoute1DataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2AeoRoute1FacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"GetV2AeoRoute1FacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Co2EmissionsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAggregatesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataParams)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalAggregateProductionDataParams)(nil)).Elem(),
	},
	"PostV2CoalAggregateProductionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalAggregateProductionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalAggregateProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalAggregateProductionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalConsumptionAndQualityDataParams)(nil)).Elem(),
	},
	"PostV2CoalConsumptionAndQualityDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalConsumptionAndQualityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalConsumptionAndQualityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalConsumptionAndQualityFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalExportsImportsQuantityPriceDataParams)(nil)).Elem(),
	},
	"PostV2CoalExportsImportsQuantityPriceDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalExportsImportsQuantityPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalExportsImportsQuantityPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalExportsImportsQuantityPriceFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMarketSalesPriceDataParams)(nil)).Elem(),
	},
	"PostV2CoalMarketSalesPriceDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalMarketSalesPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMarketSalesPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMarketSalesPriceFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalMineProductionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMineProductionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalMineProductionDataParams)(nil)).Elem(),
	},
	"PostV2CoalMineProductionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalMineProductionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalMineProductionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalMineProductionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalMineProductionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalPriceByRankDataParams)(nil)).Elem(),
	},
	"PostV2CoalPriceByRankDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalPriceByRankDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalPriceByRankDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalPriceByRankFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalReservesCapacityDataParams)(nil)).Elem(),
	},
	"PostV2CoalReservesCapacityDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalReservesCapacityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalReservesCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalReservesCapacityFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsByMineByPlantDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsByMineByPlantDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsByMineByPlantDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsByMineByPlantDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsByMineByPlantFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineAggregatesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineAggregatesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsMineStateAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineStateAggregatesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsMineStateAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsMineStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsMineStateAggregatesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantAggregatesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantAggregatesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsPlantStateAggregatesDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantStateAggregatesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsPlantStateAggregatesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsPlantStateAggregatesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsPlantStateAggregatesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CoalShipmentsReceiptsDataParams)(nil)).Elem(),
	},
	"PostV2CoalShipmentsReceiptsDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CoalShipmentsReceiptsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CoalShipmentsReceiptsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CoalShipmentsReceiptsFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2CrudeOilImportsDataParams)(nil)).Elem(),
	},
	"PostV2CrudeOilImportsDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2CrudeOilImportsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2CrudeOilImportsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2CrudeOilImportsFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCapacityByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCapacityByRegionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCapacityByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCapacityByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCapacityByRegionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassCharacteristicsByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCharacteristicsByRegionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassCharacteristicsByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassCharacteristicsByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassCharacteristicsByRegionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassExportSalesAndPriceDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassExportSalesAndPriceDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassExportSalesAndPriceDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassExportSalesAndPriceDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassExportSalesAndPriceFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassFeedstocksAndCostDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassFeedstocksAndCostDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassFeedstocksAndCostDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassFeedstocksAndCostDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassFeedstocksAndCostFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassInventoriesByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassInventoriesByRegionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassInventoriesByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassInventoriesByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassInventoriesByRegionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassProductionByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassProductionByRegionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassProductionByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassProductionByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassProductionByRegionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassSalesAndPriceByRegionDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassSalesAndPriceByRegionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassSalesAndPriceByRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassSalesAndPriceByRegionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2DensifiedBiomassWoodPelletPlantsDataParams)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassWoodPelletPlantsDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2DensifiedBiomassWoodPelletPlantsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2DensifiedBiomassWoodPelletPlantsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2DensifiedBiomassWoodPelletPlantsFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityElectricPowerOperationalDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityElectricPowerOperationalDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityElectricPowerOperationalDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityElectricPowerOperationalDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityElectricPowerOperationalDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityFacilityFuelDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityFacilityFuelDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityFacilityFuelDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityFacilityFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityFacilityFuelFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityOperatingGeneratorCapacityDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityOperatingGeneratorCapacityDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityOperatingGeneratorCapacityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityOperatingGeneratorCapacityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityOperatingGeneratorCapacityFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRetailSalesDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRetailSalesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRetailSalesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRetailSalesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRetailSalesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyFuelTypeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyFuelTypeDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyFuelTypeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyFuelTypeDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyInterchangeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyInterchangeDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyInterchangeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyInterchangeDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoDailyRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionSubBaDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoDailyRegionSubBaDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoDailyRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoDailyRegionSubBaDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoFuelTypeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoFuelTypeDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoFuelTypeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoFuelTypeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoFuelTypeDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoInterchangeDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoInterchangeDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoInterchangeDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoInterchangeDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoInterchangeDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityRtoRegionSubBaDataDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionSubBaDataDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityRtoRegionSubBaDataDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityRtoRegionSubBaDataDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityRtoRegionSubBaDataFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricitySepWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesCapabilityDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesCapabilityDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesCapabilityDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesCapabilityDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesCapabilityFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesMetersDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesMetersDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesMetersDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesMetersDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesMetersFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesNetMeteringDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesNetMeteringDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesNetMeteringDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesNetMeteringDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSourceDispositionDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSourceDispositionDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSourceDispositionDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSourceDispositionDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2ElectricityStateElectricityProfilesSummaryDataParams)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSummaryDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2ElectricityStateElectricityProfilesSummaryDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2ElectricityStateElectricityProfilesSummaryDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2ElectricityStateElectricityProfilesSummaryFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerIeoWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerConstructWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerGetDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerGetDataParams)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerPostDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerPostDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*EIAAPIControllersDatasetAeoIeoIeoControllerPostDataJSONRequestBody)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"EIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2InternationalWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2InternationalDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2InternationalDataParams)(nil)).Elem(),
	},
	"PostV2InternationalDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2InternationalDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2InternationalDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2InternationalFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2InternationalFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NaturalGasWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1WithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2WithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2DataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*GetV2NaturalGasRoute1Route2DataParams)(nil)).Elem(),
	},
	"PostV2NaturalGasRoute1Route2DataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NaturalGasRoute1Route2DataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*PostV2NaturalGasRoute1Route2DataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2FacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
	},
	"GetV2NaturalGasRoute1Route2FacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*Route1)(nil)).Elem(),
		reflect.TypeOf((*Route2)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutagesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesFacilityNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesFacilityNuclearOutagesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesFacilityNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesFacilityNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesFacilityNuclearOutagesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesGeneratorNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesGeneratorNuclearOutagesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesGeneratorNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesGeneratorNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2NuclearOutagesUsNuclearOutagesDataParams)(nil)).Elem(),
	},
	"PostV2NuclearOutagesUsNuclearOutagesDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2NuclearOutagesUsNuclearOutagesDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2NuclearOutagesUsNuclearOutagesDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2NuclearOutagesUsNuclearOutagesFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"GetV2SedsWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SedsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2SedsDataParams)(nil)).Elem(),
	},
	"PostV2SedsDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2SedsDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2SedsDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2SedsFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SedsFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2SteoWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SteoDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2SteoDataParams)(nil)).Elem(),
	},
	"PostV2SteoDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2SteoDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2SteoDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2SteoFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2SteoFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
	},
	"GetV2TotalEnergyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2TotalEnergyDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*GetV2TotalEnergyDataParams)(nil)).Elem(),
	},
	"PostV2TotalEnergyDataWithBodyWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*string)(nil)).Elem(),
		reflect.TypeOf((*io.Reader)(nil)).Elem(),
	},
	"PostV2TotalEnergyDataWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*PostV2TotalEnergyDataJSONRequestBody)(nil)).Elem(),
	},
	"GetV2TotalEnergyFacetWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
	},
	"GetV2TotalEnergyFacetFacetIdWithResponse": {
		reflect.TypeOf((*context.Context)(nil)).Elem(),
		reflect.TypeOf((*FacetId)(nil)).Elem(),
	},
	"ParseGetV2Response": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2AeoResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2AeoRoute1Response": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2AeoRoute1DataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2AeoRoute1DataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2AeoRoute1FacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2AeoRoute1FacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2Co2EmissionsCo2EmissionsAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAggregatesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2Co2EmissionsCo2EmissionsAndCarbonCoefficientsFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalAggregateProductionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalAggregateProductionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalAggregateProductionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalAggregateProductionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalAggregateProductionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalConsumptionAndQualityResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalConsumptionAndQualityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalConsumptionAndQualityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalConsumptionAndQualityFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalConsumptionAndQualityFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalExportsImportsQuantityPriceResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalExportsImportsQuantityPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalExportsImportsQuantityPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalExportsImportsQuantityPriceFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalExportsImportsQuantityPriceFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMarketSalesPriceResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMarketSalesPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalMarketSalesPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMarketSalesPriceFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMarketSalesPriceFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMineProductionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMineProductionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalMineProductionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMineProductionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalMineProductionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalPriceByRankResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalPriceByRankDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalPriceByRankDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalPriceByRankFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalPriceByRankFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalReservesCapacityResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalReservesCapacityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalReservesCapacityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalReservesCapacityFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalReservesCapacityFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsByMineByPlantResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsByMineByPlantDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsByMineByPlantDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsByMineByPlantFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsByMineByPlantFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineAggregatesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsMineAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineAggregatesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineAggregatesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineStateAggregatesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineStateAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsMineStateAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineStateAggregatesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsMineStateAggregatesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantAggregatesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsPlantAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantAggregatesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantAggregatesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantStateAggregatesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantStateAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsPlantStateAggregatesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantStateAggregatesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsPlantStateAggregatesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsReceiptsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsReceiptsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CoalShipmentsReceiptsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsReceiptsFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CoalShipmentsReceiptsFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CrudeOilImportsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CrudeOilImportsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2CrudeOilImportsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CrudeOilImportsFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2CrudeOilImportsFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCapacityByRegionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCapacityByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassCapacityByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCapacityByRegionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCapacityByRegionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassCharacteristicsByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassCharacteristicsByRegionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassExportSalesAndPriceResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassExportSalesAndPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassExportSalesAndPriceDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassExportSalesAndPriceFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassExportSalesAndPriceFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassFeedstocksAndCostResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassFeedstocksAndCostDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassFeedstocksAndCostDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassFeedstocksAndCostFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassFeedstocksAndCostFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassInventoriesByRegionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassInventoriesByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassInventoriesByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassInventoriesByRegionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassInventoriesByRegionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassProductionByRegionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassProductionByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassProductionByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassProductionByRegionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassProductionByRegionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassSalesAndPriceByRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassSalesAndPriceByRegionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassWoodPelletPlantsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassWoodPelletPlantsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2DensifiedBiomassWoodPelletPlantsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassWoodPelletPlantsFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2DensifiedBiomassWoodPelletPlantsFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityElectricPowerOperationalDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityElectricPowerOperationalDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityElectricPowerOperationalDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityElectricPowerOperationalDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityElectricPowerOperationalDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityFacilityFuelResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityFacilityFuelDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityFacilityFuelDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityFacilityFuelFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityFacilityFuelFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityOperatingGeneratorCapacityResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityOperatingGeneratorCapacityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityOperatingGeneratorCapacityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityOperatingGeneratorCapacityFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityOperatingGeneratorCapacityFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRetailSalesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRetailSalesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRetailSalesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRetailSalesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRetailSalesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyFuelTypeDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyFuelTypeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoDailyFuelTypeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyFuelTypeDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyFuelTypeDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyInterchangeDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyInterchangeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoDailyInterchangeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyInterchangeDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyInterchangeDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoDailyRegionDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoDailyRegionSubBaDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoDailyRegionSubBaDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoFuelTypeDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoFuelTypeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoFuelTypeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoFuelTypeDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoFuelTypeDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoInterchangeDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoInterchangeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoInterchangeDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoInterchangeDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoInterchangeDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoRegionDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionSubBaDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionSubBaDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityRtoRegionSubBaDataDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionSubBaDataFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityRtoRegionSubBaDataFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricitySepResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesCapabilityDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesCapabilityFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesEmissionsByStateByFuelDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEmissionsByStateByFuelFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesEnergyEfficiencyDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesEnergyEfficiencyFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesMetersResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesMetersDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesMetersDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesMetersFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesMetersFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesNetMeteringDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesNetMeteringFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesSourceDispositionDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSourceDispositionFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSummaryResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSummaryDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2ElectricityStateElectricityProfilesSummaryDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSummaryFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2ElectricityStateElectricityProfilesSummaryFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerIeoResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerConstructResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerGetDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerPostDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseEIAAPIControllersDatasetAeoIeoIeoControllerRouteFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2InternationalResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2InternationalDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2InternationalDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2InternationalFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2InternationalFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasRoute1Response": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasRoute1Route2Response": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasRoute1Route2DataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2NaturalGasRoute1Route2DataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasRoute1Route2FacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NaturalGasRoute1Route2FacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2NuclearOutagesFacilityNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesFacilityNuclearOutagesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2NuclearOutagesGeneratorNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesGeneratorNuclearOutagesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesUsNuclearOutagesResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesUsNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2NuclearOutagesUsNuclearOutagesDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesUsNuclearOutagesFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2NuclearOutagesUsNuclearOutagesFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SedsResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SedsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2SedsDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SedsFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SedsFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SteoResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SteoDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2SteoDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SteoFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2SteoFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2TotalEnergyResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2TotalEnergyDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParsePostV2TotalEnergyDataResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2TotalEnergyFacetResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
	"ParseGetV2TotalEnergyFacetFacetIdResponse": {
		reflect.TypeOf((*http.Response)(nil)).Elem(),
	},
}
